### Name: popdiv
### Title: Population diversity function
### Aliases: popdiv
### Keywords: utilities

### ** Examples


## Note : In the examples below the number of burn-in and sampling
## iterations is set to 100 so that these examples run in a reasonable
## time. In practice we recommend setting these parameters much higher so
## that convergence of the Markov chain to the stationary distribution is
## more likely. 

 ###############
 ## EXAMPLE 1 ##
 ###############

 ## SNP dataset from Nicholson et al. (2002). 66 loci, 4 populations 

 ex1 <- read.table(paste(.path.package("popgen"), "example_data1", sep = .Platform$file.sep))
 ex1 <- matrix(unlist(ex1), 66, 13, byrow = FALSE)
 NUMA <- ex1[,1]
 N <- ex1[, 2:5]
 X <- ex1[, 6:13]
 L <- 66
 P <- 4

 res <- popdiv(L, P, NUMA, N, X, burnin = 100, iter = 100, m = 10, csd = 0.01, outc = TRUE)

 plot(c(0, 100), c(0, max(res$C.sample)), type = "n")
 lines(1:100, res$C.sample[, 1])
 lines(1:100, res$C.sample[, 2], col = 2)
 lines(1:100, res$C.sample[, 3], col = 3)
 lines(1:100, res$C.sample[, 4], col = 4)

 ###############
 ## EXAMPLE 2 ##
 ###############

 ## Simulated dataset from the Multinomial-Dirichlet model.
 ## 100 loci, 3 populations.
 ## Variance parameters set to 0.01, 0.02, 0.04.
 ## Each loci has a variable number of alleles (between 3 and 8)).
 ## Dataset stored in the following format :-
 ##  - each individuals genotypes are stored in 2 rows of the file.
 ##  - the first entry in each row specifies the individuals population.
 ##  - each row has (L + 1) entries where L is the number of loci. 
 ## To examine the datafile use edit(ex2)

 
 ex2 <- read.table(paste(.path.package("popgen"), "example_data2", sep = .Platform$file.sep))
 X <- matrix(unlist(ex2), nrow(ex2), ncol(ex2), byrow = FALSE)

 X1 <- popdiv.convert(X)

 res1 <- popdiv(L = nrow(X1$N), P = ncol(X1$N), NUMA = X1$NUMA, N = X1$N, X = X1$X, burnin = 100, iter = 100, m = 10, csd = 0.01, outc = TRUE)

 plot(c(0, 100), c(0, max(res1$C.sample)), type = "n")
 lines(1:100, res1$C.sample[, 1])
 lines(1:100, res1$C.sample[, 2], col = 2)
 lines(1:100, res1$C.sample[, 3], col = 3)

  


