### Name: ps
### Title: Parametric model-based inference of population structure.
### Aliases: ps
### Keywords: utilities

### ** Examples

  X <- simMD(60, 3, 100, p = NULL, c.vec1 = c(0.1, 0.2, 0.3), c.vec2 =
1, ac = 2, beta = 1)

  ## infer the population structure
  ## NB in this example the burn-in and no. of iterations have been set
  ##    way too low so that the examples run in a reasonable time at time
  ##    of installation. To get reliable answers set these parameters
  ##    much higher and check convergence of the chain using multiple runs.

  res2 <- ps(X,
           2,
           num.sample = 100,
           burn.in = 100,
           na.lab = (-1),
           c.init = rep(0.1, 2),
           c.prior.mu = 0.01,
           c.prior.sd = 0.05,
           c.sd = 0.05,
           alpha.start = 1.0,
           fix.alpha = FALSE,
           fix.pi  = FALSE,
           popdif.flag = TRUE,
           beta = 1,
           z.init = NULL,
           fix.z = FALSE)

  res3 <- ps(X,
           3,
           num.sample = 100,
           burn.in = 100,
           na.lab = (-1),
           c.init = rep(0.1, 3),
           c.prior.mu = 0.01,
           c.prior.sd = 0.05,
           c.sd = 0.05,
           alpha.start = 1.0,
           fix.alpha = FALSE,
           fix.pi  = FALSE,
           popdif.flag = TRUE,
           beta = 1,
           z.init = NULL,
           fix.z = FALSE)

  res4 <- ps(X,
           4,
           num.sample = 100,
           burn.in = 100,
           na.lab = (-1),
           c.init = rep(0.1, 4),
           c.prior.mu = 0.01,
           c.prior.sd = 0.05,
           c.sd = 0.05,
           alpha.start = 1.0,
           fix.alpha = FALSE,
           fix.pi  = FALSE,
           popdif.flag = TRUE,
           beta = 1,
           z.init = NULL,
           fix.z = FALSE)

  k.dist <- c(res2$log.PX.K, res3$log.PX.K, res4$log.PX.K)
  k.dist <- k.dist - max(k.dist)
  k.dist <- exp(k.dist) / sum(exp(k.dist))
  k.dist

  ## print the mean values of the c parameters
  mean(res3$c[, 1])
  mean(res3$c[, 2])
  mean(res3$c[, 3])

  ## print out the results
  par(mfcol = c(3, 3))
  hist(res3$c[, 1], n = 100, xlim = c(0, 0.4))
  hist(res3$c[, 2], n = 100, xlim = c(0, 0.4))
  hist(res3$c[, 3], n = 100, xlim = c(0, 0.4))

  plot(res3$c[, 1], typ = "l")
  plot(res3$c[, 2], typ = "l")
  plot(res3$c[, 3], typ = "l")

  image(res3$Q)




